// Copyright 2025 gRPC authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef GRPC_TEST_CPP_SLEUTH_TOOL_OPTIONS_H
#define GRPC_TEST_CPP_SLEUTH_TOOL_OPTIONS_H

#include <optional>
#include <string>

#include "test/cpp/sleuth/client.h"
#include "absl/strings/string_view.h"

namespace grpc_sleuth {

Client::Options ToolClientOptions(
    absl::string_view protocol,
    std::optional<std::string> channel_creds_type_opt);

}  // namespace grpc_sleuth

#endif  // GRPC_TEST_CPP_SLEUTH_TOOL_OPTIONS_H
